@@ -608,7 +608,6 @@
 #include <mail_version.h>
 #include <mail_run.h>
 #include <mail_dict.h>
-#include <compat_level.h>
 
 /* Application-specific. */
 
@@ -934,11 +933,6 @@ int     main(int argc, char **argv)
 	}
     }
 
-    /*
-     * For consistency with mail_params_init().
-     */
-    compat_level_relop_register();
-
     /*
      * We don't enforce import_environment consistency in this program.
      * 
